/*
 * config.cpp
 * Copyright (C) Aitor Cuadrado Zubizarreta <aitor_czr@gnuinos.org>
 * 
 * ulogout is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * ulogout is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * See the COPYING file. * 
 */


#include <iostream>
#include <ini.h>

#include "config.h"

typedef struct
{
    const char *logo;
    const char *shutdown;
    const char *lock;
    const char *suspend;
    const char *hibernate;
    const char *reboot;
    const char *logout;
} configuration;

static int handler(void* user, const char* section, const char* name,
                   const char* value)
{
    configuration* pconfig = (configuration*)user;

    #define MATCH(s, n) strcmp(section, s) == 0 && strcmp(name, n) == 0
    if (MATCH("frontend", "logo")) {
        pconfig->logo = strdup(value);
    } else if (MATCH("backend", "shutdown")) {
        pconfig->shutdown = strdup(value);
    }else if (MATCH("backend", "lock")) {
        pconfig->lock = strdup(value);
    } else if (MATCH("backend", "suspend")) {
        pconfig->suspend = strdup(value);
    } else if (MATCH("backend", "hibernate")) {
        pconfig->hibernate = strdup(value);
    } else if (MATCH("backend", "reboot")) {
        pconfig->reboot = strdup(value);
    } else if (MATCH("backend", "logout")) {
        pconfig->logout = strdup(value);
    } else {
        return 0;  /* unknown section/name, error */
    }
    return 1;
}

Config::Config(int argc, char **argv)
{   
	/* set defaults */
    configuration config;
    config.logo = NULL;
    config.shutdown = NULL;
    config.lock = NULL;
    config.suspend = NULL;
    config.hibernate = NULL;
    config.reboot = NULL;
    config.logout = NULL;
  
	for(int i=0; i<argc; i++)
		argvs.push_back(std::string(argv[i]));

    if (ini_parse("/etc/ulogout/ulogout.ini", handler, &config) < 0) {
        printf("Can't load '/etc/ulogout/ulogout.ini'\n");
        exit(EXIT_FAILURE);
    }

	LOGO = config.logo;		
	SHUTDOWN_CMD = config.shutdown;
	LOCK_CMD = config.lock;
	SUSPEND_CMD = config.suspend;
	HIBERNATE_CMD = config.hibernate;
	REBOOT_CMD = config.reboot;
	LOGOUT_CMD = config.logout;

    if (config.logo)
        free((void*)config.logo);
    if (config.shutdown)
        free((void*)config.shutdown);
    if (config.lock)
        free((void*)config.lock);
    if (config.suspend)
        free((void*)config.suspend);
    if (config.hibernate)
        free((void*)config.hibernate);
    if (config.reboot)
        free((void*)config.reboot);
    if (config.logout)
        free((void*)config.logout);
	
	get_current_path();
	get_pixmaps();
}

Config::~Config()
{
	
}

void Config::get_current_path()
{
	char current_working_dir[1024] = {0}; 
	getcwd(current_working_dir, 1024);	
	CURRENT_PATH = std::string(current_working_dir);
	std::cout << "Current path is " << CURRENT_PATH << std::endl;
}

void Config::get_pixmaps()
{
	Glib::RefPtr<Gio::File> ref_path_A = Gio::File::create_for_path((CURRENT_PATH + "/images/if.png").c_str());
	Glib::RefPtr<Gio::File> ref_path_B = Gio::File::create_for_path("/usr/share/ulogout/images/" + LOGO);

	std::string path;
	
	if ( ref_path_A->query_exists() )
		path = CURRENT_PATH + "/images/";

	else if ( ref_path_B->query_exists() )
		path = "/usr/share/ulogout/images/";
  
	else std::cerr << " Image's path doesn't exist! " << std::endl;
	
	LOGO = path + LOGO;
	SHUTDOWN_ICON = path + "shutdown.png";
	CANCEL_ICON = path + "cancel.png";
	LOCK_ICON = path + "lock.png";
	SUSPEND_ICON = path + "suspend.png";
	HIBERNATE_ICON = path + "hibernate.png";
	REBOOT_ICON = path + "reboot.png";
	LOGOUT_ICON = path + "logout.png";
}

