 /*
 * main.cpp
 * Copyright (C) Aitor Cuadrado Zubizarreta <aitor_czr@gnuinos.org>
 * 
 * simple-netaid is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * simple-netaid is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * See the COPYING file. * 
 */


#include <gtkmm.h>
#include <vector>
#include <iostream>
#include <memory>
#include <libintl.h>
#include <locale.h>
#include <pwd.h>

#include "window_main.h"
#include "config.h"          

static const char *ubus_warning_message = "\n\
Ulogout group is not assigned to the current user \n\
account. To add an existing user account to this \n\
group on your system, use the usermod command:\n\n\
 # usermod -aG ulogout <username>\n\n\
replacing <username> with the name of the user \n\
you want to add.\n";  

int main (int argc , char **argv)
{
    char pwbuf[1024];
    struct passwd pw, *ppw;
    int errno;
    FILE *pf = NULL;
    char output[256]={0};
    bool found_ok = false;
   
    errno = getpwuid_r(getuid(), &pw, pwbuf, sizeof(pwbuf), &ppw);
    if(errno) return -1;
    else if(!ppw) return 0;
	
    pf = popen("getent group ulogout", "r");
    if(!pf) {
       printf("error opening the pipe %s\n", strerror(errno));
       exit(EXIT_FAILURE);
    }
	
    if(fgets(output, sizeof(output), pf)) {
       char *temp = NULL;
       output[strcspn(output, "\n")] = '\0';
       temp = rindex(output, ':') + 1;
	   char delim[2] = ",";
       char *token = strtok(temp, delim);
       while(token != NULL) {
          if(!strcmp(token, ppw->pw_name)) {
             found_ok = true;
             break;
          } 
          token = strtok(NULL, delim);
	   }
    }
    pclose(pf);

    if(!found_ok) {
       GtkWidget *dialog;
       gtk_init(&argc, &argv);
       dialog = gtk_message_dialog_new(NULL,
          GTK_DIALOG_DESTROY_WITH_PARENT,
          GTK_MESSAGE_WARNING,
          GTK_BUTTONS_OK,
          ubus_warning_message);
       gtk_window_set_title(GTK_WINDOW(dialog), "Unallowed operation warning");
       gtk_window_set_position (GTK_WINDOW(dialog), GTK_WIN_POS_MOUSE);
       gtk_dialog_run(GTK_DIALOG(dialog));
       gtk_widget_destroy(dialog);
    }
	
	auto params = std::make_unique<Config>(argc, argv);
  
	/* Setting the i18n environment */
	setlocale (LC_ALL, "");
  
	/* Here, we are using -> char *bindtextdomain (const char *domainname, const char *dirname) */
	bindtextdomain ("ulogout", "/usr/share/locale");
	textdomain ("ulogout");
	
#if GTK_MAJOR_VERSION == 2
	
	 Gtk::Main kit(argc, argv);
	 WindowMain window(params.get());
	 Gtk::Main::run(window);
	
#elif GTK_MAJOR_VERSION == 3

	auto app = Gtk::Application::create(argc, argv);
	WindowMain *window_main=Gtk::manage(new WindowMain(*params));	
	return app->run(*window_main);
		
#endif

}
